TableSectionSym

Struct TableSectionSym 

pub struct TableSectionSym<O> { /* private fields */ }
Table-backed section symmetry keyed by (point, orientation).

Implementations

Source

impl<O> TableSectionSym<O>
where O: Copy + Eq + Hash,

pub fn new() -> Self

Create an empty table.

pub fn insert_point( &mut self, point: PointId, orientation: O, permutation: Vec<usize>, )

Set a permutation used for a specific point and orientation.

pub fn insert_orientation(&mut self, orientation: O, permutation: Vec<usize>)

Set a default permutation for an orientation, independent of point.