MixedSectionStore

Struct MixedSectionStore 

pub struct MixedSectionStore { /* private fields */ }
Store named sections with mixed scalar types.

Implementations

Source

impl MixedSectionStore

pub fn new() -> Self

Create an empty mixed section store.

pub fn insert<T: MixedScalar>( &mut self, name: impl Into<String>, section: Section<T, VecStorage<T>>, ) -> Option<TaggedSection>

Insert a typed section into the store.

pub fn insert_tagged( &mut self, name: impl Into<String>, section: TaggedSection, ) -> Option<TaggedSection>

Insert a tagged section into the store.

pub fn get<T: MixedScalar>( &self, name: &str, ) -> Option<&Section<T, VecStorage<T>>>

Retrieve a typed section by name.

pub fn get_mut<T: MixedScalar>( &mut self, name: &str, ) -> Option<&mut Section<T, VecStorage<T>>>

Retrieve a mutable typed section by name.

pub fn get_tagged(&self, name: &str) -> Option<&TaggedSection>

Retrieve a tagged section by name.

pub fn iter(&self) -> impl Iterator<Item = (&String, &TaggedSection)>

Iterate over all named tagged sections.

pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&String, &mut TaggedSection)>

Mutably iterate over all named tagged sections.

pub fn is_empty(&self) -> bool

Return true if the store is empty.

pub fn gather_in_order(&self) -> BTreeMap<String, TaggedSectionBuffer>

Gather all tagged sections into flat buffers in atlas insertion order.

pub fn try_scatter_in_order( &mut self, buffers: &BTreeMap<String, TaggedSectionBuffer>, ) -> Result<(), MeshSieveError>

Scatter all tagged sections from flat buffers in atlas insertion order.