pub struct FieldSection<V, S: Storage<V>> { /* private fields */ }Expand description
A named field section with field-specific constraints.
Implementations
Sourceimpl<V, S> FieldSection<V, S>where
S: Storage<V>,
impl<V, S> FieldSection<V, S>where
S: Storage<V>,
Sourcepub fn new(name: impl Into<String>, section: Section<V, S>) -> Self
pub fn new(name: impl Into<String>, section: Section<V, S>) -> Self
Create a new field section with a name and data section.
Sourcepub fn section_mut(&mut self) -> &mut Section<V, S>
pub fn section_mut(&mut self) -> &mut Section<V, S>
Mutable access to the underlying section.
Sourcepub fn constraints(&self) -> &BTreeMap<PointId, Vec<DofConstraint<V>>>
pub fn constraints(&self) -> &BTreeMap<PointId, Vec<DofConstraint<V>>>
Access the constraint map for this field.
Sourcepub fn constraints_mut(
&mut self,
) -> &mut BTreeMap<PointId, Vec<DofConstraint<V>>>
pub fn constraints_mut( &mut self, ) -> &mut BTreeMap<PointId, Vec<DofConstraint<V>>>
Mutable access to the constraint map for this field.
Sourcepub fn insert_constraint(
&mut self,
point: PointId,
index: usize,
value: V,
) -> Result<(), MeshSieveError>
pub fn insert_constraint( &mut self, point: PointId, index: usize, value: V, ) -> Result<(), MeshSieveError>
Insert or update a single constraint for a point.
Sourcepub fn clear_constraints_for_point(&mut self, point: PointId)
pub fn clear_constraints_for_point(&mut self, point: PointId)
Remove all constraints for a point.
Sourcepub fn clear_constraints(&mut self)
pub fn clear_constraints(&mut self)
Remove all constraints.
Sourcepub fn apply_constraints(&mut self) -> Result<(), MeshSieveError>where
V: Clone,
pub fn apply_constraints(&mut self) -> Result<(), MeshSieveError>where
V: Clone,
Apply all stored constraints to the underlying section.