DiscretizationCapability

Struct DiscretizationCapability 

pub struct DiscretizationCapability {
    pub cell_type: CellType,
    pub dimension: usize,
    pub basis_families: &'static [BasisFamily],
    pub degree_range: (usize, usize),
    pub quadrature_families: &'static [QuadratureFamily],
    pub geometry_order_range: (usize, usize),
    pub finite_volume: bool,
}
One row in the supported PetscFE/PetscFV-equivalent discretization matrix.

Fields

cell_type: CellType

Canonical cell topology.

dimension: usize

Topological dimension.

basis_families: &'static [BasisFamily]

Lagrange node/basis families supported for this topology.

degree_range: (usize, usize)

Inclusive polynomial degree range supported by the runtime tabulator.

quadrature_families: &'static [QuadratureFamily]

Quadrature families supported for this topology.

geometry_order_range: (usize, usize)

Inclusive coordinate geometry order range supported by element assembly.

finite_volume: bool

Whether cell-centered FV stencils/geometry are supported.