pub struct TableSectionSym<O> { /* private fields */ }Expand description
Table-backed section symmetry keyed by (point, orientation).
Implementations
Sourceimpl<O> TableSectionSym<O>
impl<O> TableSectionSym<O>
Sourcepub fn insert_point(
&mut self,
point: PointId,
orientation: O,
permutation: Vec<usize>,
)
pub fn insert_point( &mut self, point: PointId, orientation: O, permutation: Vec<usize>, )
Set a permutation used for a specific point and orientation.
Sourcepub fn insert_orientation(&mut self, orientation: O, permutation: Vec<usize>)
pub fn insert_orientation(&mut self, orientation: O, permutation: Vec<usize>)
Set a default permutation for an orientation, independent of point.