pub struct MixedSectionStore { /* private fields */ }Expand description
Store named sections with mixed scalar types.
Implementations
Sourceimpl MixedSectionStore
impl MixedSectionStore
Sourcepub fn insert<T: MixedScalar>(
&mut self,
name: impl Into<String>,
section: Section<T, VecStorage<T>>,
) -> Option<TaggedSection>
pub fn insert<T: MixedScalar>( &mut self, name: impl Into<String>, section: Section<T, VecStorage<T>>, ) -> Option<TaggedSection>
Insert a typed section into the store.
Sourcepub fn insert_tagged(
&mut self,
name: impl Into<String>,
section: TaggedSection,
) -> Option<TaggedSection>
pub fn insert_tagged( &mut self, name: impl Into<String>, section: TaggedSection, ) -> Option<TaggedSection>
Insert a tagged section into the store.
Sourcepub fn get<T: MixedScalar>(
&self,
name: &str,
) -> Option<&Section<T, VecStorage<T>>>
pub fn get<T: MixedScalar>( &self, name: &str, ) -> Option<&Section<T, VecStorage<T>>>
Retrieve a typed section by name.
Sourcepub fn get_mut<T: MixedScalar>(
&mut self,
name: &str,
) -> Option<&mut Section<T, VecStorage<T>>>
pub fn get_mut<T: MixedScalar>( &mut self, name: &str, ) -> Option<&mut Section<T, VecStorage<T>>>
Retrieve a mutable typed section by name.
Sourcepub fn get_tagged(&self, name: &str) -> Option<&TaggedSection>
pub fn get_tagged(&self, name: &str) -> Option<&TaggedSection>
Retrieve a tagged section by name.
Sourcepub fn iter(&self) -> impl Iterator<Item = (&String, &TaggedSection)>
pub fn iter(&self) -> impl Iterator<Item = (&String, &TaggedSection)>
Iterate over all named tagged sections.
Sourcepub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (&String, &mut TaggedSection)>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&String, &mut TaggedSection)>
Mutably iterate over all named tagged sections.
Sourcepub fn gather_in_order(&self) -> BTreeMap<String, TaggedSectionBuffer>
pub fn gather_in_order(&self) -> BTreeMap<String, TaggedSectionBuffer>
Gather all tagged sections into flat buffers in atlas insertion order.
Sourcepub fn try_scatter_in_order(
&mut self,
buffers: &BTreeMap<String, TaggedSectionBuffer>,
) -> Result<(), MeshSieveError>
pub fn try_scatter_in_order( &mut self, buffers: &BTreeMap<String, TaggedSectionBuffer>, ) -> Result<(), MeshSieveError>
Scatter all tagged sections from flat buffers in atlas insertion order.